# ================================================================
# Examples of the documentation of Model HT.n:
# HT.n-1.3: Exclusion vs. inclusion
# Data from Yonelinas (1994), Exp.3
#
# Date of creation: October, 2009
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-HT-n.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# DATA OF YONELINAS (1994), Experiment 2: WEAK LISTS
data.weak  <-   c(969, 576, 403, 282, 215, 115,   # Distractors
                  296, 200, 153, 141, 180, 130,   # Exclusion items
                  194, 190, 150, 135, 177, 254)   # Inclusion items

# DATA OF YONELINAS (1994), Experiment 2: STRONG LISTS
data.strong <-   c(969, 576, 403, 282, 215, 115,  # Distractors
                   351, 170, 150, 120, 162, 187,  # Exclusion items
                   167, 132, 123, 136, 210, 372)  # Inclusion items

n <- 3

#===============================================================================
#
# 1. HT.3 MODEL: 
#
#===============================================================================
# Specification of constraints
fixed.dist <- matrix(c(rep(0, 6),  1,                             # Distractors
                             1:6,  7), nr = 2, byrow = T)
                         
fixed.exc.inc <- matrix(c(rep(0, 6),        1,  1,                # Fixed constraints exclusion / inclusion
                              14:16, 20:22, 9, 18), nr = 2, byrow = T)
                        
fixed <- cbind(fixed.dist, fixed.exc.inc)
ident <- matrix(c(11:13,   8, 10,
                  25:23,  17, 19), nr = 2, byrow = T)

# Compute start parameter vector
par <- SDT.HT.n.start.par(n, data.weak)

# Add redundant parameters so that their positions can be seen in the output
fixed.show <- HT.n.Redundant.to.Fixed(par, n, fixed, ident)

# Compute Parameter information
Par.Info <- SDT.Parameter.Info(par = par, n = n, Model.Id = "HT.n", fixed = fixed.show, ident = ident)
cat("\n-------------------------------------------------------------\n")
cat("HT.3: Yonelinas (1994), Exp.3, Parameter-Information:")
cat("\n-------------------------------------------------------------\n")
print(Par.Info)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.3: Yonelinas (1994), Exp.3, weak lists")
cat("\n------------------------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(par = par.start, data = data.weak, n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.3: Yonelinas (1994), Exp.3, strong lists")
cat("\n------------------------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(data = data.strong, n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

#===============================================================================
#
# 2. HT.3 MODEL: FREE VARIANCE
#
#===============================================================================
fixed.exc.inc <- matrix(c(rep(0, 6),                       # Fixed constraints exclusion / inclusion
                              14:16, 20:22), nr = 2, byrow = T)
                        
fixed <- cbind(fixed.dist, fixed.exc.inc)
ident <- matrix(c(11:13,    8:9, 10,
                  25:23,  17:18, 19), nr = 2, byrow = T)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.3: Yonelinas (1994), Exp.3, weak lists, FREE VARIANCE PARAMETER")
cat("\n------------------------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(data = data.weak, n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.3: Yonelinas (1994), Exp.3, strong lists, FREE VARIANCE PARAMETER")
cat("\n------------------------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(data = data.strong, n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

#===============================================================================
#
# 3. HT.2 MODEL: 
#
#===============================================================================

# Fixed constraints:
fixed.exc.inc <- matrix(c(rep(0, 8),        1,  1,                # Fixed constraints exclusion / inclusion
                              13:16, 20:23, 9, 18), nr = 2, byrow = T)
fixed <- cbind(fixed.dist, fixed.exc.inc)

# Equality constraints:
ident <- matrix(c(11:12,   8, 10,
                  25:24,  17, 19), nr = 2, byrow = T)

# Add redundant parameters so that their positions can be seen in the output
fixed.show <- HT.n.Redundant.to.Fixed(par, n, fixed, ident)

# Compute Parameter information
Par.Info.HT.2 <- SDT.Parameter.Info(par = par, n = n, Model.Id = "HT.n", fixed = fixed.show, ident = ident)
cat("\n-------------------------------------------------------------\n")
cat("HT.2: Kelley & Wixted, Exp.3, Parameter-Information:")
cat("\n-------------------------------------------------------------\n")
print(Par.Info.HT.2)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.2: Yonelinas (1994), Exp.3, weak lists")
cat("\n------------------------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(data = data.weak, n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.2: Yonelinas (1994), Exp.3, strong lists")
cat("\n------------------------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(data = data.strong, n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

#===============================================================================
#
# 4. HT.2 MODEL: FREE VARIANCE
#
#===============================================================================
fixed.exc.inc <- matrix(c(rep(0, 8),                       # Fixed constraints exclusion / inclusion
                              13:16, 20:23), nr = 2, byrow = T)
                        
fixed <- cbind(fixed.dist, fixed.exc.inc)
ident <- matrix(c(11:12,    8:9, 10,
                  25:24,  17:18, 19), nr = 2, byrow = T)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.2: Yonelinas (1994), Exp.3, weak lists, FREE VARIANCE PARAMETER")
cat("\n------------------------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(data = data.weak, n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.2: Yonelinas (1994), Exp.3, stong lists, FREE VARIANCE PARAMETER")
cat("\n------------------------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(data = data.strong, n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)
