# ================================================================
# MIX-2.2: Examples of the documentation of Model MIX-2:
# Modeling associative recognition data of Kelley & Wixted, Exp.2
#
# Date of creation: July, 2009
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-2.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))


# DATA OF KELLEY & WIXTED (2001), Experiment 2
data <- c(879, 553, 345,  61,  54,  28,	# Exp.2: Lure items
          179, 109,  82,  45,  28,  37,   # Exp.2: Weak   Items, rearranged
	     81,  69,  62,  31,  37, 200,	# Exp.2: Weak   Items, intact
	    215,  82,  60,  31,  31,  61,	# Exp.2: Strong Items, rearranged
 	     21,  24,  33,  21,  33, 348)	# Exp.2: Strong Items, intact


# NUMBER OF CONDITIONS (TYPES OF SIGNALS)
n <- 5		

# GENERATE A TABLE OF PARAMETERS SERVING AS A GUIDE FOR SPECIFYING
# CONSTRAINTS ON PARAMETERS
par <- SDT.MIX2.start.par(n, data)
cat("\n----------------------------------------------------------\n")
cat(" Parameters of the MIX.2-Model:")
cat("\n----------------------------------------------------------\n")
par.list <- data.frame(name = MIX2.par.names(par, n), par)
print(par.list)

# 1. SPECIFY FIXED CONSTRAINTS		
# 1.1 FIX PARAMETERS FOR THE LURE DISTRIBUTION: p.1 = 0, m.11 = m.12 = 0, sd.11 = sd.12 = 1  
#			    p.1 m.11 m.12 sd.11 sd.12
fixed.lure <- matrix(c( 0,   0,   0,   1,   1,
	   	            1,   2,   4,   3,   5), nr = 2, byrow = T)

# 1.2 FUNCTIONAL CONSTRAINTS ON MEANS (SEE BELOW)
#                     m.31 m.32 m.41 m.51 m.52
fixed.fct <- matrix(c(   0,   0,   0,   0,   0,
	   	            22,  24,  32,  42,  44), nr = 2, byrow = T)
	   	            
# 1.3 COMBINE FIXED CONSTRAINTS
fixed <- cbind(fixed.lure, fixed.fct)


# 2. SPECIFY EQUALITY CONSTRAINTS: IDENTICAL PROBABILITIES AND THRESHOLD IDENTICAL
# 2.1 IDENTICAL THRESHOLDS
ident.th <- matrix(c(6:10,    6:10,    6:10,    6:10,
	   	      6:10+10, 6:10+20, 6:10+30, 6:10+40), nr = 2, byrow = T)

# 2.2 IDENTICAL SD FOR STRONG SIGNALS AND IDENTICAL SD FOR WEAK SIGNALS
ident.sd <- matrix(c(   8,    8,     8,  8+20,  8+20,   8+20,
	   	         8+10,   10, 10+10, 10+30, 10+20,  10+30), nr = 2, byrow = T)

ident.sd <- matrix(c(   13,   13,    13, 13+20, 13+20,  13+20,
	   	         13+10,   15, 15+10, 13+30, 15+20,  15+30), nr = 2, byrow = T)

# 2.3 COMBINE EQUALITY CONSTRAINTS
ident <- cbind(ident.th, ident.sd)


# 3. SPECIFY FUNCTIONAL CONSTRAINTS
fct.m <- function(par)
{
	# Positions of target means
	m.31 <- 22			# Target index: m.31
	m.32 <- 24			# Target index: m.32
	m.41 <- 32			# Target index: m.41
	m.51 <- 42			# Target index: m.51
	m.52 <- 44			# Target index: m.52

	# Positions of source means
	m.21 <- 12			# Source index: m.21
	m.22 <- 14              # Source index: m.22
	m.42 <- 34			# Source index: m.42	

	# Constraints:
	par[m.32] <- par[m.22]					# Fix "middle" distributions, weak   pair
	par[m.52] <- par[m.42]					# Fix "middle" distributions, strong pair

 	par[m.31] <-  par[m.22]	+ par[m.22] - par[m.21]	# Right =  middle + d'.ass     (weak)
	par[m.41] <-  par[m.42] + par[m.21] - par[m.22]	# Left  =  middle - d'.ass     (strong)
	par[m.51] <-  par[m.42] - par[m.21] + par[m.22]	# Right =  middle + d'.ass	 (strong)

	# Define Gradient function
	gr.fct <- function(grad, par)
	{
		grad[m.21] <- grad[m.21] -   grad[m.31] + grad[m.41] - grad[m.51]
		grad[m.22] <- grad[m.22] + 2*grad[m.31] + grad[m.32] - grad[m.41] + grad[m.51]
		grad[m.42] <- grad[m.42] +   grad[m.52] + grad[m.41] + grad[m.51] 
	
		return(grad)
	}
	attr(par, "gradient") <- gr.fct			# Gradient
	return(par)
}

# 4. SPECIFY JACOBIAN ASSOCIATED WITH FUNCTIONAL CONSTRAINTS
J.fct <- function(par)
{
	# Positions of target means
	m.31 <- 22			# Target index: m.31
	m.32 <- 24			# Target index: m.32
	m.41 <- 32			# Target index: m.41
	m.51 <- 42			# Target index: m.51
	m.52 <- 44			# Target index: m.52

	# Positions of source means
	m.21 <- 12			# Source index: m.21
	m.22 <- 14              # Source index: m.22
	m.42 <- 34			# Source index: m.42	

      J <- diag(length(par))
	
      # Implement Constraints:
	J[m.32, m.22] <-  1					
	J[m.52, m.42] <-  1
	
	J[m.31, m.22] <-  2
	J[m.31, m.21] <- -1
	
	J[m.41, m.42] <-  1
	J[m.41, m.21] <-  1
	J[m.41, m.22] <- -1

	J[m.51, m.42] <-  1
	J[m.51, m.21] <- -1
	J[m.51, m.22] <-  1
      J
} 
  
attr(fct.m, "Jacobian") <- J.fct			# Jacobian matrix

cat("\n---------------------------------------------------------------------\n")
cat(" MIX-2: Associative recognition (Data from Kelley and Wixted, Exp.2:")
cat("\n---------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti.Obj <- SDT.Estimate(data = data, Model.Id = "MIX.2", n = n, fixed = fixed, ident = ident, functional = fct.m, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)
print(Stat.Obj)

# PLOT GAUSSIAN DISTRIBUTIONS AND THRESHOLDS:
# PLOT DENSITY CURVES
SDT.Plot(Opti.Obj, cols = c(6, 6, 3, 3, 3, 3, 4, 4, 4, 4), SDT.legend = list(text = c("New", paste("Weak", 1:3),paste("Strong", 1:3)), cols =c(6, 3, 3, 3, 4, 4, 4)))

# PLOT ROC CURVES
# Plot ROC curve with data
SDT.Plot(Opti.Obj, cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1), labels = c("False Alarms", "Hits"), option = "ROC+",
SDT.legend = list(text = c("weak rearranged", "weak intact","strong rearranged", "strong intact"), cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1)))

# Plot z-ROC curve with data
SDT.Plot(Opti.Obj, cols = c(3, 3, 4, 4), ltys= c(2, 1, 2, 1), labels = c("z(FA)", "z(H)"), option = "zROC+",
SDT.legend = list(text = c("weak rearranged", "weak intact","strong rearranged", "strong intact"), cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1)))
