# ================================================================
# Examples of the documentation of Model MIX-PD:
# MIX-PD.2-3: Modeling Associative Recognition
# Data from Kelley and Wixted, Exp.3
#
# Date of creation: August, 2009
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-PD.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))


# DATA OF KELLEY & WIXTED (2001), Experiment 3
data <- c(662, 302, 208,  33,  30,   5,	# Exp.3: Lure   items
	    119,  66,  55,  24,  15,  31,	# Exp.3: Weak   Items, rearranged
	     41,  37,  49,  18,  27, 138,	# Exp.3: Weak   Items, intact
	    151,  41,  44,  21,  22,  31,	# Exp.3: Strong Items, rearranged
	      9,  10,  17,  19,  34, 221)

# NUMBER OF CONDITIONS (TYPES OF SIGNALS)
n <- 5

# IDENTITY CONSTRAINTS. p.left = p.right, d'.left = d'.right
ident <- matrix(c(3, 5, 3+6, 5+6,
	   	      4, 6, 4+6, 6+6), nr = 2, byrow = T)

# IDENTITY CONSTRAINTS. d'.left = d'.right
ident.d <- matrix(c(5, 5+6,
	   	        6, 6+6), nr = 2, byrow = T)

# IDENTITY CONSTRAINTS. d'.left = d'.right (strong = weak)
ident.d.w.s <- matrix(c(5,   5,   5,
	     	            6, 5+6, 6+6), nr = 2, byrow = T)

# IDENTITY CONSTRAINTS. m (weak) = m (strong) sd (weak) = sd (strong)
ident.m.sd <- matrix(c(1,   2,
	     	           7, 2+6), nr = 2, byrow = T)


cat("\n----------------------------------------------------------------------\n")
cat(" MIX.PD: Associative recognition (Data from Kelley and Wixted, Exp.3:")
cat("\n p.left  = p.right, d'.left  = d'.right") 
cat("\n----------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti.Obj <- SDT.Estimate(data = data, Model.Id = "MIX.PD", n = n, ident = ident, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)
print(Stat.Obj)

cat("\n----------------------------------------------------------------------\n")
cat(" MIX.PD: Associative recognition (Data from Kelley and Wixted, Exp.3):")
cat("\n p.left  <> p.right, d'.left  = d'.right") 
cat("\n----------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti.Obj <- SDT.Estimate(data = data, Model.Id = "MIX.PD", n = n, ident = ident.d, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)
print(Stat.Obj)

cat("\n----------------------------------------------------------------------\n")
cat(" MIX.PD: Associative recognition (Data from Kelley and Wixted, Exp.3):")
cat("\n p.left  <> p.right, d'.left  = d'.right (weak = strong)") 
cat("\n----------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti.Obj <- SDT.Estimate(data = data, Model.Id = "MIX.PD", n = n, ident = ident.d.w.s, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)
print(Stat.Obj)

cat("\n----------------------------------------------------------------------\n")
cat(" MIX.PD: Associative recognition (Data from Kelley and Wixted, Exp.3):")
cat("\n p.left  <> p.right, d'.left  = d'.right (weak = strong)") 
cat("\n m (weak) = m (strong), sd (weak) = sd (strong)") 
cat("\n----------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti.Obj <- SDT.Estimate(data = data, Model.Id = "MIX.PD", n = n, ident = cbind(ident.d.w.s, ident.m.sd), test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)
print(Stat.Obj)


# RE-ESTIMATE PRVIOUS MODEL USING THE ESTIMATED PARAMETER-VECTOR OF THE LAST FITTED MODEL AS START PARAMETER:
cat("\n----------------------------------------------------------------------\n")
cat(" MIX.PD: Associative recognition (Data from Kelley and Wixted, Exp.3):")
cat("\n p.left  <> p.right, d'.left  = d'.right (weak = strong)") 
cat("\n DIFFERNT STARTING VALUE OF PARAMETERS!")
cat("\n----------------------------------------------------------------------\n")

# RE-ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti.Obj <- SDT.Estimate(par = Opti.Obj$SDT.full.par, data = data, Model.Id = "MIX.PD", n = n, ident = ident.d.w.s, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)
print(Stat.Obj)

cat("\n---------------------------------------------------------------------------------------------\n")
cat(" MIX-PD: Associative recognition (Data from Kelley and Wixted, Exp.3): Parameter Information")
cat("\n--------------------------------------------------------------------------------------------\n")
# COMPUTE AND PRINT PARAMETER INFORMATION
pinfo <- SDT.Parameter.Info(data = Opti.Obj$SDT.data, par = Opti.Obj$SDT.full.par, n = Opti.Obj$SDT.n, Model.Id = Opti.Obj$SDT.Model.Id, 
                              fixed = Opti.Obj$SDT.fixed, ident = Opti.Obj$SDT.ident)
print(pinfo)

# PLOT RESULTS
SDT.Plot(Opti.Obj, cols = c(1, 3, 3, 3, 4, 4, 4), SDT.legend = list(text = c("New", paste("weak", 1:3),paste("strong", 1:3))))